complete -c git-warp-time -s d -l dirty -d 'Include files tracked by Git but modifications in the working tee'
complete -c git-warp-time -s i -l ignored -d 'Include files tracked by Git but also ignored'
complete -c git-warp-time -s q -l quiet -d 'Don\'t print any output about files touched or skipped'
complete -c git-warp-time -s h -l help -d 'Print help'
